@@ -2,26 +2,56 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: simulation.Rnw:53-55
+### code chunk number 1: simulation.Rnw:72-74
 ###################################################
 library(actuar)
-options(width = 62, digits = 4)
+options(width = 60, digits = 4)
 
 
 ###################################################
-### code chunk number 2: simulation.Rnw:89-90 (eval = FALSE)
+### code chunk number 2: simulation.Rnw:143-145
+###################################################
+rmixture(10, probs = c(2, 1),
+         models = expression(rexp(3), rexp(7)))
+
+
+###################################################
+### code chunk number 3: simulation.Rnw:198-200
+###################################################
+rcompound(10, rpois(1.5), rgamma(3, 2))
+rcomppois(10, 1.5, rgamma(3, 2))
+
+
+###################################################
+### code chunk number 4: simulation.Rnw:232-237
+###################################################
+x <- rcomppois(1e5, 3.5,
+               rmixture(probs = c(2, 1, 0.5),
+                        expression(rgamma(3),
+                                   rgamma(5, 4),
+                                   rlnorm(2, 1))))
+
+
+###################################################
+### code chunk number 5: simulation.Rnw:243-244
+###################################################
+mean(x)
+
+
+###################################################
+### code chunk number 6: simulation.Rnw:277-278 (eval = FALSE)
 ###################################################
 ## rpois(n, rgamma(n, 3, rgamma(n, 2, 2)))
 
 
 ###################################################
-### code chunk number 3: simulation.Rnw:266-267
+### code chunk number 7: simulation.Rnw:444-445
 ###################################################
 set.seed(3)
 
 
 ###################################################
-### code chunk number 4: simulation.Rnw:269-280
+### code chunk number 8: simulation.Rnw:447-460
 ###################################################
 nodes <- list(cohort = 2,
               contract = c(4, 3),
@@ -33,11 +63,13 @@ ms <- expression(cohort = rnorm(2, sqrt(0.1)),
                  contract = rnorm(cohort, 1),
                  year = rlnorm(contract, 1))
 wijt <- runif(31, 0.5, 2.5)
-pf <- simul(nodes = nodes, model.freq = mf, model.sev = ms, weights = wijt)
+pf <- simul(nodes = nodes,
+            model.freq = mf, model.sev = ms,
+            weights = wijt)
 
 
 ###################################################
-### code chunk number 5: simulation.Rnw:287-290
+### code chunk number 9: simulation.Rnw:467-470
 ###################################################
 class(pf)
 pf$data
@@ -45,64 +77,65 @@ pf$classification
 
 
 ###################################################
-### code chunk number 6: simulation.Rnw:302-303
+### code chunk number 10: simulation.Rnw:482-483
 ###################################################
 pf
 
 
 ###################################################
-### code chunk number 7: simulation.Rnw:311-313
+### code chunk number 11: simulation.Rnw:491-493
 ###################################################
 aggregate(pf)
 aggregate(pf, by = c("cohort", "year"), FUN = mean)
 
 
 ###################################################
-### code chunk number 8: simulation.Rnw:320-322
+### code chunk number 12: simulation.Rnw:500-502
 ###################################################
 frequency(pf)
 frequency(pf, by = "cohort")
 
 
 ###################################################
-### code chunk number 9: simulation.Rnw:338-340
+### code chunk number 13: simulation.Rnw:518-520
 ###################################################
 severity(pf)
 severity(pf, splitcol = 1)
 
 
 ###################################################
-### code chunk number 10: simulation.Rnw:345-346
+### code chunk number 14: simulation.Rnw:525-526
 ###################################################
 weights(pf)
 
 
 ###################################################
-### code chunk number 11: simulation.Rnw:351-352
+### code chunk number 15: simulation.Rnw:531-532
 ###################################################
 aggregate(pf, classif = FALSE) / weights(pf, classif = FALSE)
 
 
 ###################################################
-### code chunk number 12: simulation.Rnw:380-382
+### code chunk number 16: simulation.Rnw:560-562
 ###################################################
 set.seed(123)
 options(width = 55)
 
 
 ###################################################
-### code chunk number 13: simulation.Rnw:384-386
+### code chunk number 17: simulation.Rnw:564-566
 ###################################################
 wit <- rgamma(15, rep(runif(3, 0, 100), each = 5),
               rep(runif(3, 0, 100), each = 5))
 
 
 ###################################################
-### code chunk number 14: simulation.Rnw:394-398
+### code chunk number 18: simulation.Rnw:574-579
 ###################################################
 frequency(simul(list(entity = 3, year = 5),
-      expression(entity = rgamma(rgamma(1, 5, 5), rgamma(1, 25, 1)),
-          year = rpois(weights * entity)),
-      weights = wit))
+                expression(entity = rgamma(rgamma(1, 5, 5),
+                                           rgamma(1, 25, 1)),
+                           year = rpois(weights * entity)),
+                weights = wit))
 
 
