@@ -1,9 +1,13 @@
 /*
- *  Native routines registration, as per "Writing R extensions".
+ *  Native routines registration, as per "Writing R extensions" and
+ *  definition of native interface to one routine exported by package
+ *  expint.
+ *
  */
 
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
+#include <expintAPI.h>		/* optional; for expressiveness */
 #include "actuar.h"
 
 static const R_ExternalMethodDef ExternalEntries[] = {
@@ -18,4 +22,7 @@ static const R_ExternalMethodDef ExternalEntries[] = {
 void R_init_actuar(DllInfo *dll)
 {
     R_registerRoutines(dll, NULL, NULL, NULL, ExternalEntries);
+
+    /* native interface to routine from package expint */
+    actuar_gamma_inc = (double(*)(double,double)) R_GetCCallable("expint", "gamma_inc");
 }
