@@ -134,6 +134,6 @@ double levinvweibull(double limit, double shape, double scale, double order,
 
     double u = exp(shape * (log(scale) - log(limit)));
 
-    return R_pow(scale, order) * gammaint_raw(u, 1.0 - order/shape)
+    return R_pow(scale, order) * actuar_gamma_inc(1.0 - order/shape, u)
         + ACT_DLIM__0(limit, order) * (0.5 - exp(-u) + 0.5);
 }
